app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("testWrongInputInBounds")

app$setInputs(addDimension = "click")
app$setInputs(upperBound2 = "a")
app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runSpotIter = "click")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(upperBound2 = 2)
app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runSpotIter = "click")
Sys.sleep(5)
app$snapshot(list(output = "resultTable"))
